@@ -48,7 +48,7 @@ typedef struct __syncpkg_t {
 } syncpkg_t;
 
 int sync_synctree();
-int downloadfiles(PMList *servers, char *localpath, PMList *files);
+int downloadfiles(PMList *servers, const char *localpath, PMList *files);
 syncpkg_t* find_pkginsync(char *needle, PMList *haystack);
 
 #endif
